# XCASH-Ecosystem-api-wrapper


Pip package of wrappers arround various RestApi related to XCASH Foundation ecosystem

Integrated:

- [X] Blockchain explorer
    - [X] Examples
- [X] DPOPS Delegate explorer
    - [X] Examples
- [X] Shared delegate API
    - [X] Examples
- [ ] Pypi (PIP) deployment


